binomial_control: Set computational options for the sampling algorithms

View source: R/f_binomial.R

binomial_controlR Documentation

Set computational options for the sampling algorithms

Description

Set computational options for the sampling algorithms

Usage

binomial_control(PG.approx = TRUE, PG.approx.m = -2L, probit.HaarPXDA = TRUE)

Arguments

PG.approx

whether Polya-Gamma draws for logistic binomial models are approximated by a hybrid gamma convolution approach. If not, BayesLogit::rpg is used, which is exact for some values of the shape parameter.

PG.approx.m

if PG.approx=TRUE, the number of explicit gamma draws in the sum-of-gammas representation of the Polya-Gamma distribution. The remainder (infinite) convolution is approximated by a single moment-matching gamma draw. Special values are: -2L for a default choice depending on the value of the shape parameter balancing performance and accuracy, -1L for a moment-matching normal approximation, and 0L for a moment-matching gamma approximation.

probit.HaarPXDA

only used for binomial models with probit link. If supported, probit.HaarPXDA=TRUE and the Haar PX-DA sandwich step is added to the Albert-Chib data augmentation scheme for probit multilevel models. This will usually result in a faster mixing MCMC algorithm. Currently supported when all coefficients are sampled in a single Gibbs block and all coefficients' prior means equal zero.

Value

A list with computational options.


mcmcsae documentation built on July 21, 2026, 1:06 a.m.