| cMVN_control | R Documentation |
Set options for fast sampling from a degenerate multivariate normal distribution
cMVN_control(
eps1 = sqrt(.Machine$double.eps),
eps2 = sqrt(.Machine$double.eps),
chol.control = chol_control()
)
eps1 |
scalar parameter to control numerical robustness against singularity of Q. |
eps2 |
scalar parameter associated with the constraint part to control numerical robustness. |
chol.control |
options for Cholesky decomposition, see |
A list of options used by the constrained MVN sampler.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.