f_multi: Specify a multi-response sampling distribution

View source: R/f_multi.R

f_multiR Documentation

Specify a multi-response sampling distribution

Description

This function can be used in the family argument of create_sampler or generate_data to specify a multi-response sampling distribution. The current implementation requires the data to be in long format, disregarding the possibility that observations may be on the same units.

Usage

f_multi(fam.list, fam.ind)

Arguments

fam.list

a named list of response types.

fam.ind

a formula specifying a character or factor variable indicating which observations are of each response type specified in fam.list.

Value

A family object.


mcmcsae documentation built on July 21, 2026, 1:06 a.m.