View source: R/f_multinomial.R
| f_multinomial | R Documentation |
This function can be used in the family argument of create_sampler
or generate_data to specify a multinomial sampling distribution. This
includes the special case of categorical (multinoulli) data.
f_multinomial(
link = "logit",
n.trial = NULL,
K = NULL,
control = multinomial_control()
)
link |
the name of a link function. Currently the only allowed link function
for the multinomial distribution is |
n.trial |
the number of multinomial trials. This can be specified either as a formula for a variable number of trials, or as a scalar value for a common number of trials for all units. |
K |
number of categories for multinomial model; only used for prior predictive sampling. |
control |
a list with computational options. These options can
be specified using function |
For the multinomial family, the left hand side of the formula argument of
create_sampler can be specified in one of the following ways:
as a single factor, character, boolean or integer variable, say y.
The categories then correspond to the levels of as.factor(y). This option
can only be used for categorical data.
as a n x (K-1) numeric matrix with values between 0 and 1, where n is the
number of observations and K the number of categories. The values are interpreted
as proportions of observations in each category. This requires specifying the number
of multinomial trials through argument n.trial.
a K-column integer matrix, where K is the number of categories, each column containing the number of 'successes' for the corresponding category.
A family object.
y <- factor(sample(c("a", "b", "c"), 800, prob=c(0.3, 0.5, 0.2), replace=TRUE))
sampler <- create_sampler(y ~ 0 + cat_, family=f_multinomial())
sim <- MCMCsim(sampler, n.chain=2, burnin=200, n.iter=300, verbose=FALSE)
summary(sim)
summary(predict(sim, newdata=data.frame(id=1:5)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.