gaussian_control: Set computational options for the sampling algorithms

gaussian_controlR Documentation

Set computational options for the sampling algorithms

Description

Set computational options for the sampling algorithms

Usage

gaussian_control(block.V = TRUE)

Arguments

block.V

if TRUE, the default, all coefficients of reg and gen components in a variance model formula are sampled in a single block. Alternatively, a list of character vectors with names of model components whose coefficients should be sampled together in blocks.

Value

A list with computational options.


mcmcsae documentation built on July 21, 2026, 1:06 a.m.