These functions are intended for use in the family argument of create_sampler.
In future versions these functions may gain additional arguments, but currently the corresponding
functions gaussian and binomial can be used as well.
f_gaussian(link = "identity")f_binomial(link = c("logit", "probit"))
f_negbinomial(link = "logit")
f_poisson(link = "log")
f_multinomial(link = "logit", K = NULL)
A family object.
the name of a link function. Currently the only allowed link functions are:
"identity" for (log-)Gaussian sampling distributions, "logit" (default) and "probit"
for binomial distributions and "log" for negative binomial sampling distributions.
number of categories for multinomial model; this must be specified for prior predictive sampling.