| negbinomial_control | R Documentation |
Set computational options for the sampling algorithms
negbinomial_control(PG.approx = TRUE, PG.approx.m = -2L, CRT.approx.m = 20L)
PG.approx |
whether Polya-Gamma draws for logistic binomial models are
approximated by a hybrid gamma convolution approach. If not, |
PG.approx.m |
if |
CRT.approx.m |
scalar integer specifying the degree of approximation to sampling from a Chinese Restaurant Table distribution. The approximation is based on Le Cam's theorem. Larger values yield a slower but more accurate sampler. |
A list with computational options for the sampling algorithm.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.