| poisson_control | R Documentation |
Set computational options for the sampling algorithms
poisson_control(nb.shape = 100, PG.approx = TRUE, PG.approx.m = -2L)
nb.shape |
shape parameter of the negative binomial distribution used internally to approximate the Poisson distribution. This should be set to a relatively large value (default is 100), corresponding to negligible overdispersion, to obtain a good approximation to the Poisson sampling distribution. However, note that very large values may cause slow MCMC exploration of the posterior distribution. |
PG.approx |
whether Polya-Gamma draws for logistic binomial models are
approximated by a hybrid gamma convolution approach. If not, |
PG.approx.m |
if |
A list with computational options for the sampling algorithm.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.