Learn R Programming

mcmcsae (version 0.8.1)

cMVN_control: Set options for fast sampling from a degenerate multivariate normal distribution

Description

Set options for fast sampling from a degenerate multivariate normal distribution

Usage

cMVN_control(
  eps1 = sqrt(.Machine$double.eps),
  eps2 = sqrt(.Machine$double.eps),
  chol.control = chol_control()
)

Value

A list of options used by the constrained MVN sampler.

Arguments

eps1

scalar parameter to control numerical robustness against singularity of Q.

eps2

scalar parameter associated with the constraint part to control numerical robustness.

chol.control

options for Cholesky decomposition, see chol_control.