Learn R Programming

mcmcsae (version 0.8.1)

create_block_cMVN_sampler: Set up a a function for direct sampling from a constrained multivariate normal distribution

Description

Set up a a function for direct sampling from a constrained multivariate normal distribution

Usage

create_block_cMVN_sampler(
  mbs,
  X,
  Q,
  R = NULL,
  r = NULL,
  fam,
  name = "x",
  control
)

Value

An environment with precomputed quantities and functions for sampling from a multivariate normal distribution subject to equality constraints.

Arguments

mbs

block component containing several model components.

X

design matrix.

Q

precision matrix.

R

equality restriction matrix.

r

rhs vector for equality constraints \(R'x = r\), where \(R'\) denotes the transpose of R.

fam

family object.

name

name of the cMVN vector parameter.

control

list with numerical control options, which can be set using function cMVN_control.