Set up a a function for direct sampling from a constrained multivariate normal distribution
create_block_cMVN_sampler(
mbs,
X,
Q,
R = NULL,
r = NULL,
fam,
name = "x",
control
)An environment with precomputed quantities and functions for sampling from a multivariate normal distribution subject to equality constraints.
block component containing several model components.
design matrix.
precision matrix.
equality restriction matrix.
rhs vector for equality constraints \(R'x = r\), where \(R'\) denotes the transpose of R.
family object.
name of the cMVN vector parameter.
list with numerical control options, which can be set using function cMVN_control.