| f_multi | R Documentation |
This function can be used in the family argument of create_sampler
or generate_data to specify a multi-response sampling distribution.
The current implementation requires the data to be in long format, disregarding
the possibility that observations may be on the same units.
f_multi(fam.list, fam.ind)
fam.list |
a named list of response types. |
fam.ind |
a formula specifying a character or factor variable indicating
which observations are of each response type specified in |
A family object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.