Learn R Programming

mcmcsae (version 0.8.1)

gaussian_control: Set computational options for the sampling algorithms

Description

Set computational options for the sampling algorithms

Usage

gaussian_control(block.V = TRUE)

Value

A list with computational options.

Arguments

block.V

if TRUE, the default, all coefficients of reg and gen components in a variance model formula are sampled in a single block. Alternatively, a list of character vectors with names of model components whose coefficients should be sampled together in blocks.