Set computational options for the sampling algorithms
gaussian_control(block.V = TRUE)A list with computational options.
if TRUE, the default, all coefficients of reg
and gen components in a variance model formula are sampled in a
single block. Alternatively, a list of character vectors with names of
model components whose coefficients should be sampled together in blocks.