Set computational options for the sampling algorithms
negbinomial_control(PG.approx = TRUE, PG.approx.m = -2L, CRT.approx.m = 20L)A list with computational options for the sampling algorithm.
whether Polya-Gamma draws for logistic binomial models are
approximated by a hybrid gamma convolution approach. If not, BayesLogit::rpg
is used, which is exact for some values of the shape parameter.
if PG.approx=TRUE, the number of explicit gamma draws in the
sum-of-gammas representation of the Polya-Gamma distribution. The remainder (infinite)
convolution is approximated by a single moment-matching gamma draw. Special values are:
-2L for a default choice depending on the value of the shape parameter
balancing performance and accuracy, -1L for a moment-matching normal approximation,
and 0L for a moment-matching gamma approximation.
scalar integer specifying the degree of approximation to sampling from a Chinese Restaurant Table distribution. The approximation is based on Le Cam's theorem. Larger values yield a slower but more accurate sampler.