Set computational options for the sampling algorithms
poisson_control(nb.shape = 100, PG.approx = TRUE, PG.approx.m = -2L)A list with computational options for the sampling algorithm.
shape parameter of the negative binomial distribution used internally to approximate the Poisson distribution. This should be set to a relatively large value (default is 100), corresponding to negligible overdispersion, to obtain a good approximation to the Poisson sampling distribution. However, note that very large values may cause slow MCMC exploration of the posterior distribution.
whether Polya-Gamma draws for logistic binomial models are
approximated by a hybrid gamma convolution approach. If not, BayesLogit::rpg
is used, which is exact for some values of the shape parameter.
if PG.approx=TRUE, the number of explicit gamma draws in the
sum-of-gammas representation of the Polya-Gamma distribution. The remainder (infinite)
convolution is approximated by a single moment-matching gamma draw. Special values are:
-2L for a default choice depending on the value of the shape parameter
balancing performance and accuracy, -1L for a moment-matching normal approximation,
and 0L for a moment-matching gamma approximation.